@@ -64,7 +64,11 @@ def convert_argument_to_port(
     if inspect.isclass(cls):
         # Generic Cases
 
-        if issubclass(cls, bool) or (default is not None and isinstance(default, bool)):
+        if (
+            not issubclass(cls, Enum)
+            and issubclass(cls, bool)
+            or (default is not None and isinstance(default, bool))
+        ):
             t = ArgPortInput(
                 kind=PortKindInput.BOOL,
                 widget=widget,
@@ -74,7 +78,11 @@ def convert_argument_to_port(
             )  # catch bool is subclass of int
             return t
 
-        if issubclass(cls, int) or (default is not None and isinstance(default, int)):
+        if (
+            not issubclass(cls, Enum)
+            and issubclass(cls, int)
+            or (default is not None and isinstance(default, int))
+        ):
             return ArgPortInput(
                 kind=PortKindInput.INT,
                 widget=widget,
@@ -82,7 +90,11 @@ def convert_argument_to_port(
                 default=default,
                 nullable=nullable,
             )
-        if issubclass(cls, str) or (default is not None and isinstance(default, str)):
+        if (
+            not issubclass(cls, Enum)
+            and issubclass(cls, str)
+            or (default is not None and isinstance(default, str))
+        ):
             return ArgPortInput(
                 kind=PortKindInput.STRING,
                 widget=widget,
